@@ -380,7 +380,7 @@ IOReturn IOFWAsyncCommand::complete(IOReturn status)
         }
         else if(fDevice) 
 		{
-            IOLog("Command for device %p that's gone away\n", fDevice);
+         //   IOLog("Command for device %p that's gone away\n", fDevice);
             completion_status = kIOReturnOffline;	// device must have gone.
         }
     }
@@ -548,4 +548,4 @@ void IOFWAsyncCommand::setResponseCode( UInt32 rcode )
 UInt32 IOFWAsyncCommand::getResponseCode( void ) const
 {
 	return fMembers->fResponseCode;
-}
\ No newline at end of file
+}
