@@ -3,20 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -410,7 +409,8 @@ static void	RunTalkingDCLEngine( UInt32* packetHeader, DCLCommand** ppCurrentDCL
 	DCLCallProc*			pDCLCallProc;
 	DCLJump*				pDCLJump;
 	DCLSetTagSyncBits*		pDCLSetTagSyncBits;
-
+	UInt32					host_header;
+	
 	// Run the current DCL command.
 	pCurrentDCLCommand = *ppCurrentDCLCommand;
 	switch (pCurrentDCLCommand->opcode & ~kFWDCLOpFlagMask)
@@ -454,9 +454,11 @@ static void	RunTalkingDCLEngine( UInt32* packetHeader, DCLCommand** ppCurrentDCL
 
 		case kDCLSetTagSyncBitsOp :
 			pDCLSetTagSyncBits = (DCLSetTagSyncBits*) pCurrentDCLCommand;
-			*packetHeader &= ~(kFWIsochTag | kFWIsochSy);
-			*packetHeader |= (pDCLSetTagSyncBits->tagBits << kFWIsochTagPhase);
-			*packetHeader |= (pDCLSetTagSyncBits->syncBits << kFWIsochSyPhase);
+			host_header = OSSwapBigToHostInt32( *packetHeader );
+			host_header &= ~(kFWIsochTag | kFWIsochSy);
+			host_header |= (pDCLSetTagSyncBits->tagBits << kFWIsochTagPhase);
+			host_header |= (pDCLSetTagSyncBits->syncBits << kFWIsochSyPhase);
+			*packetHeader = OSSwapHostToBigInt32( host_header );
 			pCurrentDCLCommand = pCurrentDCLCommand->pNextDCLCommand;
 			*pGetNextPacket = false;
 			break;
@@ -547,7 +549,7 @@ IODCLTranslator::ListeningDCLPingPongProc(DCLCommand* pDCLCommand)
         packetBuffer = (UInt8 *)pDCLTransferPacket->buffer;
         packetHeader = *((UInt32 *) packetBuffer);
         packetBuffer += sizeof (UInt32);
-        packetSize = (packetHeader & kFWIsochDataLength) >> kFWIsochDataLengthPhase;
+        packetSize = (OSSwapBigToHostInt32(packetHeader) & kFWIsochDataLength) >> kFWIsochDataLengthPhase;
 
         // Run this packet through DCL program.
         getNextPacket = false;
@@ -606,8 +608,8 @@ void IODCLTranslator::TalkingDCLPingPongProc(DCLCommand* pDCLCommand)
         packetSize -= 4;//zzz not the best way
         packetHeader =
                 (packetSize << kFWIsochDataLengthPhase) |
-                (me->fPacketHeader & ~(kFWIsochDataLength));
-        *((UInt32 *) packetBuffer) = packetHeader;
+                (OSSwapBigToHostInt32(me->fPacketHeader) & ~(kFWIsochDataLength));
+        *((UInt32 *) packetBuffer) = OSSwapHostToBigInt32(packetHeader);
 
         // Update send packet DCL.
         packetSize += 4;//zzz really, not the best way
@@ -642,7 +644,7 @@ IOReturn IODCLTranslateTalk::compile(IOFWSpeed speed, UInt32 chan)
     if(!fHWProgram)
         return kIOReturnInternalError;
 
-    fPacketHeader = chan << kFWIsochChanNumPhase;
+    fPacketHeader = OSSwapHostToBigInt32( chan << kFWIsochChanNumPhase );
 
     // Create label for start of loop.
     fStartLabel.pNextDCLCommand = (DCLCommand*)pDCLTransferPacket;
@@ -706,7 +708,7 @@ IOReturn IODCLTranslateListen::compile(IOFWSpeed speed, UInt32 chan)
     if(!fHWProgram)
         return kIOReturnInternalError;
 
-    fPacketHeader = chan << kFWIsochChanNumPhase;
+    fPacketHeader = OSSwapHostToBigInt32( chan << kFWIsochChanNumPhase );
 
     // Create label for start of loop.
     fStartLabel.pNextDCLCommand = (DCLCommand*)pDCLTransferPacket;
