@@ -175,24 +175,181 @@ void IOFWIsochChannel::free()
 #pragma mark -
 //////////////////////////////////////////////////////////////////////////////////////////
 
+// checkMemoryInRange
+//
+//
+
+IOReturn IOFWIsochChannel::checkMemoryInRange( IOMemoryDescriptor * memory )
+{
+	IOReturn status = kIOReturnSuccess;
+
+	if( memory == NULL )
+	{
+		status = kIOReturnBadArgument;
+	}
+	
+	//
+	// setup
+	//
+	
+	bool memory_prepared = false;
+	if( status == kIOReturnSuccess )
+	{
+		status = memory->prepare( kIODirectionInOut );
+	}
+	
+	if( status == kIOReturnSuccess )
+	{
+		memory_prepared = true;
+	}
+	
+	UInt64 length = 0;
+	if( status == kIOReturnSuccess )
+	{
+		length = memory->getLength();
+		if( length == 0 )
+		{
+			status = kIOReturnError;
+		}
+	}
+	
+	//
+	// create IODMACommand
+	//
+	
+	IODMACommand * dma_command = NULL;
+	if( status == kIOReturnSuccess )
+	{
+		dma_command = IODMACommand::withSpecification( 
+												kIODMACommandOutputHost64,		// segment function
+												64,								// max address bits
+												length,							// max segment size
+												(IODMACommand::MappingOptions)(IODMACommand::kMapped | IODMACommand::kIterateOnly),		// IO mapped & don't bounce buffer
+												length,							// max transfer size
+												0,								// page alignment
+												NULL,							// mapper
+												NULL );							// refcon
+		if( dma_command == NULL )
+			status = kIOReturnError;
+		
+	}
+	
+	if( status == kIOReturnSuccess )
+	{
+		// set memory descriptor and don't prepare it
+		status = dma_command->setMemoryDescriptor( memory, false ); 
+	}	
+
+	bool dma_command_prepared = false;
+	if( status == kIOReturnSuccess )
+	{
+		status = dma_command->prepare( 0, length, true );
+	}
+
+	if( status == kIOReturnSuccess )
+	{
+		dma_command_prepared = true;
+	}
+	
+	//
+	// check ranges
+	//
+
+	if( status == kIOReturnSuccess )
+	{
+		UInt64 offset = 0;
+		UInt64 mask = fControl->getFireWirePhysicalAddressMask();
+		while( (offset < length) && (status == kIOReturnSuccess) )
+		{
+			IODMACommand::Segment64 segments[10];
+			UInt32 num_segments = 10;
+			status = dma_command->gen64IOVMSegments( &offset, segments, &num_segments );
+			if( status == kIOReturnSuccess )
+			{
+				for( UInt32 i = 0; i < num_segments; i++ )
+				{
+				//	IOLog( "checkSegments - segments[%d].fIOVMAddr = 0x%016llx, fLength = %d\n", i, segments[i].fIOVMAddr, segments[i].fLength  );
+						
+					if( (segments[i].fIOVMAddr & (~mask)) )
+					{
+				//		IOLog( "checkSegmentsFailed - 0x%016llx & 0x%016llx\n", segments[i].fIOVMAddr, mask );
+						status = kIOReturnNotPermitted;
+						break;
+					}
+				}
+			}
+		}
+	}
+	
+	//
+	// clean up
+	//
+	
+	if( dma_command_prepared )
+	{
+		dma_command->complete();
+		dma_command_prepared = false;
+	}
+		
+	if( dma_command )
+	{
+		dma_command->release();
+		dma_command = NULL;
+	}
+	
+	if( memory_prepared )
+	{
+		memory->complete();
+		memory_prepared = false;
+	}
+	
+	return status;
+
+}
+
 // setTalker
 //
 //
 
 IOReturn IOFWIsochChannel::setTalker( IOFWIsochPort *talker )
 {
+	IOReturn error = kIOReturnSuccess;
     fTalker = talker;
 
-	IOFWLocalIsochPort * localIsochPort = OSDynamicCast( IOFWLocalIsochPort, talker ) ;
+	IOFWLocalIsochPort * localIsochPort = OSDynamicCast( IOFWLocalIsochPort, talker );
 	if ( localIsochPort )
 	{
-		IODCLProgram * program = localIsochPort->getProgramRef() ;
-
-		program->setForceStopProc( fStopProc, fStopRefCon, this ) ;
-		program->release() ;
+		IODCLProgram * program = localIsochPort->getProgramRef();
+		IOMemoryMap * map = program->getBufferMap();
+		if( map == NULL )
+		{
+			error = kIOReturnNoMemory;
+		}
+		
+		IOMemoryDescriptor * memory = NULL;
+		if( error == kIOReturnSuccess )
+		{
+			memory = map->getMemoryDescriptor();
+			if( memory == NULL )
+			{
+				error = kIOReturnNoMemory;
+			}
+		}
+		
+		if( error == kIOReturnSuccess )
+		{
+			error = checkMemoryInRange( memory );
+		}
+		
+		if( error == kIOReturnSuccess )
+		{
+	
+			program->setForceStopProc( fStopProc, fStopRefCon, this );
+			program->release();
+		}
 	}
 
-    return kIOReturnSuccess;
+    return error;
 }
 
 // addListener
@@ -213,10 +370,33 @@ IOReturn IOFWIsochChannel::addListener( IOFWIsochPort *listener )
 		IOFWLocalIsochPort * localIsochPort = OSDynamicCast( IOFWLocalIsochPort, listener ) ;
 		if ( localIsochPort )
 		{
-			IODCLProgram * program = localIsochPort->getProgramRef() ;
+			IODCLProgram * program = localIsochPort->getProgramRef();
+			IOMemoryMap * map = program->getBufferMap();
+			if( map == NULL )
+			{
+				error = kIOReturnNoMemory;
+			}
 			
-			program->setForceStopProc( fStopProc, fStopRefCon, this ) ;
-			program->release() ;
+			IOMemoryDescriptor * memory = NULL;
+			if( error == kIOReturnSuccess )
+			{
+				memory = map->getMemoryDescriptor();
+				if( memory == NULL )
+				{
+					error = kIOReturnNoMemory;
+				}
+			}
+				
+			if( error == kIOReturnSuccess )
+			{
+				error = checkMemoryInRange( memory );
+			}
+
+			if( error == kIOReturnSuccess )
+			{			
+				program->setForceStopProc( fStopProc, fStopRefCon, this ) ;
+				program->release() ;
+			}
 		}
 	}
 	
@@ -536,7 +716,8 @@ IOReturn IOFWIsochChannel::allocateChannelBegin( 	IOFWSpeed		inSpeed,
 				status = fReadCmd->submit();
 				
 				DebugLogCond( status, "IOFWIsochChannel<%p>::allocateChannelBegin() line %u - read command got error 0x%x\n", this, __LINE__, status ) ;
-				DebugLog("IOFWIsochChannel<%p>::allocateChannelBegin() - oldIRM set to %08x %08x %08x\n", this, oldIRM[0], oldIRM[1], oldIRM[2] ) ;
+				DebugLog("IOFWIsochChannel<%p>::allocateChannelBegin() - oldIRM set to %08x %08x %08x\n", this, 
+							OSSwapBigToHostInt32(oldIRM[0]), OSSwapBigToHostInt32(oldIRM[1]), OSSwapBigToHostInt32(oldIRM[2]) ) ;
 			}
 			
 			//
@@ -545,7 +726,8 @@ IOReturn IOFWIsochChannel::allocateChannelBegin( 	IOFWSpeed		inSpeed,
 			
 			if ( fBandwidth == 0 )
 			{
-				if( ( status == kIOReturnSuccess ) && ( oldIRM[0] < bandwidth ) )
+				UInt32 old_bandwidth = OSSwapBigToHostInt32( oldIRM[0] );
+				if( ( status == kIOReturnSuccess ) && ( old_bandwidth < bandwidth ) )
 				{
 					DebugLog("IOFWIsochChannel<%p>::allocateChannelBegin() - no bandwidth left\n", this) ;
 					status = kIOReturnNoSpace;
@@ -553,7 +735,7 @@ IOReturn IOFWIsochChannel::allocateChannelBegin( 	IOFWSpeed		inSpeed,
 				
 				if( status == kIOReturnSuccess )
 				{
-					UInt32			newVal = oldIRM[0] - bandwidth;
+					UInt32			newVal = OSSwapHostToBigInt32(old_bandwidth - bandwidth);
 					
 					fLockCmd->reinit( generation, addr, &oldIRM[0], &newVal, 1 );
 		
@@ -590,8 +772,11 @@ IOReturn IOFWIsochChannel::allocateChannelBegin( 	IOFWSpeed		inSpeed,
 			{
 				unsigned channel ;
 			
+				UInt32 old_channel_hi = OSSwapBigToHostInt32( oldIRM[1] );
+				UInt32 old_channel_lo = OSSwapBigToHostInt32( oldIRM[2] );
+				
 				// mask inAllowedChans by channels IRM has available
-				inAllowedChans &= (UInt64)(oldIRM[2]) | ((UInt64)oldIRM[1] << 32);
+				inAllowedChans &= (UInt64)(old_channel_lo) | ((UInt64)old_channel_hi << 32);
 			
 				for( channel = 0; channel < 64; ++channel )
 				{
@@ -617,13 +802,13 @@ IOReturn IOFWIsochChannel::allocateChannelBegin( 	IOFWSpeed		inSpeed,
 					{
 						addr.addressLo = kCSRChannelsAvailable31_0;
 						oldPtr = &oldIRM[1];
-						newVal = *oldPtr & ~(1<<(31 - channel));
+						newVal = OSSwapHostToBigInt32( old_channel_hi & ~(1<<(31 - channel)) );
 					}
 					else
 					{
 						addr.addressLo = kCSRChannelsAvailable63_32;
 						oldPtr = &oldIRM[2];
-						newVal = *oldPtr & ~(1 << (63 - channel));
+						newVal = OSSwapHostToBigInt32( old_channel_lo & ~(1 << (63 - channel)) );
 					}
 					
 					fLockCmd->reinit( generation, addr, oldPtr, &newVal, 1 );
@@ -838,16 +1023,17 @@ void IOFWIsochChannel::reallocBandwidth( UInt32 generation )
 		while( (result == kIOReturnSuccess) && !done )
 		{
 			UInt32 newVal = 0;
+			UInt32 old_bandwidth = OSSwapBigToHostInt32( oldVal );
 			
 			// make sure there's space
-			if( oldVal < fBandwidth ) 
+			if( old_bandwidth < fBandwidth ) 
 			{
 				result = kIOReturnNoSpace;
 			}
 			
 			if( result == kIOReturnSuccess )
 			{
-				newVal = oldVal - fBandwidth;
+				newVal = OSSwapHostToBigInt32(old_bandwidth - fBandwidth);
 		
 				fLockCmd->reinit( generation, addr, &oldVal, &newVal, 1 );
 				result = fLockCmd->submit();
@@ -910,7 +1096,8 @@ void IOFWIsochChannel::reallocBandwidth( UInt32 generation )
 		bool done = false;
 		while( (result == kIOReturnSuccess) && !done )
 		{
-			UInt32 newVal = oldVal & ~mask;
+			UInt32 old_channels_avail = OSSwapBigToHostInt32( oldVal );
+			UInt32 newVal = OSSwapHostToBigInt32( old_channels_avail & ~mask );
 			if( newVal == oldVal ) 
 			{
 				// Channel already allocated!
@@ -1068,7 +1255,8 @@ IOReturn IOFWIsochChannel::releaseChannelComplete()
 			bool done = false;
 			while( (result == kIOReturnSuccess) && !done )
 			{
-				UInt32 newVal = newVal = oldVal + fBandwidth;
+				UInt32 old_bandwidth = OSSwapBigToHostInt32( oldVal );
+				UInt32 newVal = OSSwapHostToBigInt32( old_bandwidth + fBandwidth );
 		
 				fLockCmd->reinit( generation, addr, &oldVal, &newVal, 1 );
 				result = fLockCmd->submit();
@@ -1130,7 +1318,8 @@ IOReturn IOFWIsochChannel::releaseChannelComplete()
 			bool done = false;
 			while( (result == kIOReturnSuccess) && !done )
 			{
-				UInt32 newVal = oldVal | mask;
+				UInt32 old_channels_avail = OSSwapBigToHostInt32( oldVal );
+				UInt32 newVal = OSSwapHostToBigInt32( old_channels_avail | mask );
                 
 				fLockCmd->reinit( generation, addr, &oldVal, &newVal, 1 );
 				result = fLockCmd->submit();
