@@ -3,20 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -30,6 +29,12 @@
  */
 /*
 	$Log: IOFireWireFamilyCommon.h,v $
+	Revision 1.55.4.2  2006/03/10 03:59:44  collin
+	*** empty log message ***
+	
+	Revision 1.55.4.1  2005/08/06 01:31:31  collin
+	*** empty log message ***
+	
 	Revision 1.55  2005/03/12 03:27:51  collin
 	*** empty log message ***
 	
@@ -626,7 +631,8 @@ typedef enum
 {
 	kFWIsochPortDefaultOptions = 0,
 	kFWIsochPortUseSeparateKernelThread		= BIT(1),
-	kFWIsochEnableRobustness			= BIT(2)
+	kFWIsochEnableRobustness			= BIT(2),
+	kFWIsochBigEndianUpdates			= BIT(3)
 } IOFWIsochPortOptions ;
 
 // =================================================================
@@ -887,7 +893,8 @@ enum
 enum IOFWWriteFlags
 {
 	kIOFWWriteFlagsNone				= 0x0000000,
-	kIOFWWriteFlagsDeferredNotify 	= 0x00000001
+	kIOFWWriteFlagsDeferredNotify 	= 0x00000001,
+	kIOFWWriteFastRetryOnBusy		= 0x00000002
 };
 
 //
