@@ -3,20 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -32,6 +31,7 @@
 #import <IOKit/firewire/IOFireWireNub.h>
 #import <IOKit/firewire/IOFireWireController.h>
 #import <IOKit/firewire/IOConfigDirectory.h>
+#import <IOKit/firewire/IOFWSimpleContiguousPhysicalAddressSpace.h>
 
 // protected
 #import <IOKit/firewire/IOFireWireLink.h>
@@ -130,6 +130,33 @@ void IOFireWireNubAux::setTerminationState( TerminationState state )
 	fTerminationState = state;
 }
 
+// isPhysicalAccessEnabled
+//
+//
+
+bool IOFireWireNubAux::isPhysicalAccessEnabled( void )
+{
+	return false;
+}
+
+// createSimpleContiguousPhysicalAddressSpace
+//
+//
+
+IOFWSimpleContiguousPhysicalAddressSpace * IOFireWireNubAux::createSimpleContiguousPhysicalAddressSpace( vm_size_t size, IODirection direction )
+{
+	return fPrimary->fControl->createSimpleContiguousPhysicalAddressSpace( size, direction );
+}
+
+// createSimplePhysicalAddressSpace
+//
+//
+
+IOFWSimplePhysicalAddressSpace * IOFireWireNubAux::createSimplePhysicalAddressSpace( vm_size_t size, IODirection direction )
+{
+	return fPrimary->fControl->createSimplePhysicalAddressSpace( size, direction );
+}
+
 #pragma mark -
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -537,48 +564,6 @@ const CSRNodeUniqueID& IOFireWireNub::getUniqueID() const
 	return fUniqueID; 
 }
 
-/**
- ** IOUserClient methods
- **/
-
-// newUserClient
-//
-//
-
-IOReturn IOFireWireNub::newUserClient(task_t		owningTask,
-                                      void * 		/* security_id */,
-                                      UInt32  		type,
-                                      IOUserClient **	handler )
-
-{
-    IOReturn			err = kIOReturnSuccess;
-    IOFireWireUserClient *	client;
-
-    if( type != 11 )
-        return( kIOReturnBadArgument);
-
-	if( isInactive() )
-	{
-		return kIOReturnNoMemory;
-	}
-	
-    client = IOFireWireUserClient::withTask(owningTask);
-
-    if( !client || (false == client->attach( this )) ||
-        (false == client->start( this )) ) 
-	{
-        if(client) 
-		{
-            client->detach( this );
-            client->release();
-        }
-        err = kIOReturnNoMemory;
-    }
-
-    *handler = client;
-    return( err );
-}
-
 // setNodeFlags
 //
 //
@@ -603,4 +588,3 @@ UInt32 IOFireWireNub::getNodeFlags( void )
 {
 	return 0;
 }
-
