@@ -2,22 +2,21 @@
  * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ *
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
+ *
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
- * 
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
+ *
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -301,7 +300,8 @@ bool IOFireWireROMCache::hasROMChanged( const UInt32 * newBIB, UInt32 newBIBSize
 		
 		// is this a unit less, generation zero device?
 		
-		UInt32 romGeneration = (newBIB[2] & kFWBIBGeneration) >> kFWBIBGenerationPhase;
+		UInt32 bib_quad = OSSwapBigToHostInt32( newBIB[2] );
+		UInt32 romGeneration = (bib_quad & kFWBIBGeneration) >> kFWBIBGenerationPhase;
 		if( romGeneration == 0 )
 		{
 			if( fOwner->getUnitCount() == 0 )
@@ -457,7 +457,11 @@ void IOFireWireROMCache::setROMState( ROMState state, UInt32 generation )
 	}
 #endif
 
-	fState = state;
+	// no coming back from an invalid state
+	if( fState != kROMStateInvalid )
+	{
+		fState = state;
+	}
 	
 	if( fState == kROMStateResumed )
 	{
@@ -539,8 +543,9 @@ IOReturn IOFireWireROMCache::updateROMCache( UInt32 offset, UInt32 length )
                 // generation back that we know isn't up to date - so suspend the ROM
                 UInt32 oldGeneration = generation;
 				status = checkROMState( generation );
-                if(status == kIOReturnSuccess && generation == oldGeneration) {
-                    setROMState(kROMStateSuspended);
+                if(status == kIOReturnSuccess && generation == oldGeneration) 
+				{
+                    setROMState( kROMStateSuspended );
                 }
 			}
 			else if( status == kIOReturnSuccess ) 
@@ -564,6 +569,8 @@ IOReturn IOFireWireROMCache::updateROMCache( UInt32 offset, UInt32 length )
 			else
 			{
 				FWKLOG(( "%p: err 0x%x reading ROM\n", this, status ));
+				
+				setROMState( kROMStateInvalid );
 			}
 			
 			IOFree( buff, bufLen );
@@ -594,4 +601,4 @@ bool IOFireWireROMCache::serialize( OSSerialize * s ) const
 	dictionary->release();
 	
 	return ok;
-}
\ No newline at end of file
+}
