@@ -3,20 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -26,6 +25,12 @@
  * HISTORY
  *
  * $Log: IOFireWireUserClient.h,v $
+ * Revision 1.45.18.3  2006/01/31 04:49:51  collin
+ * *** empty log message ***
+ *
+ * Revision 1.45.18.1  2005/08/17 03:33:57  collin
+ * *** empty log message ***
+ *
  * Revision 1.45  2004/01/22 01:49:59  niels
  * fix user space physical address space getPhysicalSegments
  *
@@ -170,6 +175,7 @@ class IOFireWireUserClient : public IOUserClient
 		virtual IOReturn				setProperties ( OSObject * properties ) ;
 
 		// IOService
+		virtual bool					initWithTask( task_t owningTask, void * securityToken, UInt32 type, OSDictionary * properties );
 		virtual bool 					start ( IOService * provider );
 		virtual void 					stop ( IOService * provider );
 		virtual IOReturn 				message(
@@ -205,7 +211,6 @@ class IOFireWireUserClient : public IOUserClient
 
 		// me
 		
-		static IOFireWireUserClient*	withTask( task_t owningTask ) ;
 //		void							deallocateSets () ; 
 		const task_t					getOwningTask () const {return fTask;}
 		IOFireWireNub *					getOwner ()	const				{ return (IOFireWireNub*) getProvider() ; }
