@@ -2,22 +2,21 @@
  * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ *
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
+ *
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
- * 
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
+ *
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -196,7 +195,8 @@ IOReturn IOLocalConfigDirectory::incrementGeneration( void )
 IOReturn IOLocalConfigDirectory::compile(OSData *rom)
 {
     UInt32 header;
-    UInt16 crc = 0;
+    UInt32 big_header;
+	UInt16 crc = 0;
     OSData *tmp;	// Temporary data for directory entries.
     unsigned int size;
     unsigned int numEntries;
@@ -223,6 +223,7 @@ IOReturn IOLocalConfigDirectory::compile(OSData *rom)
 	{
         IOConfigEntry *entry = OSDynamicCast(IOConfigEntry, fEntries->getObject(i));
         UInt32 val;
+		UInt32 big_val;
         if(!entry)
 		{
 			IOLog(__FILE__" %d internal error!\n", __LINE__ )  ;
@@ -249,14 +250,17 @@ IOReturn IOLocalConfigDirectory::compile(OSData *rom)
 		
         val |= entry->fKey << kConfigEntryKeyValuePhase;
         val |= entry->fType << kConfigEntryKeyTypePhase;
-        crc = FWUpdateCRC16(crc, val);
 		
-        tmp->appendBytes(&val, sizeof(UInt32));
+		big_val = OSSwapHostToBigInt32( val );
+        crc = FWUpdateCRC16(crc, big_val);
+		
+        tmp->appendBytes(&big_val, sizeof(UInt32));
     }
 	
     header = numEntries << kConfigLeafDirLengthPhase;
     header |= crc;
-    rom->appendBytes(&header, sizeof(UInt32));
+	big_header = OSSwapHostToBigInt32( header );
+    rom->appendBytes(&big_header, sizeof(UInt32));
     rom->appendBytes(tmp);
     tmp->release();
 
@@ -265,6 +269,7 @@ IOReturn IOLocalConfigDirectory::compile(OSData *rom)
 	{
         IOConfigEntry *entry = OSDynamicCast(IOConfigEntry, fEntries->getObject(i));
         UInt32 val;
+		UInt32 big_val;
         if(!entry)
 		{
             return kIOReturnInternalError;	// Oops!
@@ -299,7 +304,8 @@ IOReturn IOLocalConfigDirectory::compile(OSData *rom)
 				crc = FWComputeCRC16((const UInt32 *)buffer, len / 4);
                 val = (len/4) << kConfigLeafDirLengthPhase;
                 val |= crc;
-                rom->appendBytes(&val, sizeof(UInt32));
+				big_val = OSSwapHostToBigInt32( val );
+				rom->appendBytes(&big_val, sizeof(UInt32));
                 rom->appendBytes(buffer, len);
                 break;
             }
