@@ -6,8 +6,8 @@
  *  Copyright (c) 2003 Apple Computer, Inc. All rights reserved.
  *
  *	$Log: IOFireWireLibNuDCL.h,v $
- *	Revision 1.6.24.1  2006/04/19 17:48:20  ayanowit
- *	Merged in changes for Leopard
+ *	Revision 1.6.20.1  2006/01/17 00:35:00  niels
+ *	<rdar://problem/4399365> FireWire NuDCL APIs need Rosetta support
  *	
  *	Revision 1.6  2003/08/25 08:39:17  niels
  *	*** empty log message ***
@@ -114,7 +114,7 @@ namespace IOFireWireLib {
 		public :
 		
 			UInt8		headerBytes ;
-			bool		wait ;
+			UInt8		wait ;
 			
 			inline ReceiveNuDCLSharedData() : headerBytes( 0 ), wait( false ) {}
 	} ;
