@@ -3,20 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -32,6 +31,8 @@
 #import "IOFireWireLibUnitDirectory.h"
 #import "IOFireWireLibDevice.h"
 
+#import <System/libkern/OSCrossEndian.h>
+
 namespace IOFireWireLib {
 
 	// static interface table
@@ -174,9 +175,19 @@ namespace IOFireWireLib {
 			descCString = CFStringGetChars( desc, descLen ) ;
 		}
 
+		FWAddress host_value(value);
+		
+		ROSETTA_ONLY(
+			{
+				host_value.nodeID = OSSwapInt16( value.nodeID );
+				host_value.addressHi = OSSwapInt16( value.addressHi );
+				host_value.addressLo = OSSwapInt32( value.addressLo );
+			}
+		);
+		
 		return IOConnectMethodScalarIStructureI(	mUserClient.GetUserClientConnection(), 
 													kLocalConfigDirectory_AddEntry_FWAddr, 
-													4, sizeof(value), mKernUnitDirRef, key, descCString, descLen, & value) ;
+													4, sizeof(value), mKernUnitDirRef, key, descCString, descLen, & host_value) ;
 	}
 	
 	IOReturn
