@@ -7,6 +7,8 @@
  *
  */
 
+#ifdef __cplusplus
+
 extern "C++" {
 
 #import <CoreFoundation/CoreFoundation.h>
@@ -21,4 +23,6 @@ extern "C++" {
 #import <pthread.h>
 #import <unistd.h>
 
-}
\ No newline at end of file
+}
+
+#endif
